#
# spec file for package dust
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dust
Version:        0.9.0
Release:        2.2
Summary:        A more intuitive version of du
License:        Apache-2.0
URL:            https://github.com/bootandy/dust
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.zst
Patch0:         fix-test-string.patch
BuildRequires:  cargo-packaging

%description
Dust is meant to give you an instant overview of which directories are using
disk space without requiring sort or head. Dust will print a maximum of one
'Did not have permissions message'.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        ZSH completion for %{name}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH completion script for %{name}.

%prep
%setup -qa1
%patch0 -p1

%build
%{cargo_build}

%install
%{cargo_install}
install -Dm0644 completions/_dust %{buildroot}/%{_datadir}/zsh/site-functions/_%{name}
install -Dm0644 completions/dust.bash %{buildroot}/%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 completions/dust.fish %{buildroot}/%{_datadir}/fish/completions/%{name}.fish

%check
%{cargo_test}

%files
%{_bindir}/%{name}
%license LICENSE
%doc README.md

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Wed Jan 31 2024 Joshua Smith <jsmithfpv@gmail.com>
- Added fix-test-string.patch and re-enabled test.
* Wed Jan 10 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.9.0:
  * Migrated to clap4. Command line flags must appear before
    arguments: dust -X debug target instead of dust target -X debug
  * Bars on right by default (change with new Flag -B)
  * Add flag -S (for Custom Stack size) - incase dust crashes with
    memory allocation error.
  * Add flat -I (--ignore-all-in-file) - Ignore all regexs in this
    file.
  * Clearer errors on file not found.
* Sun May  7 2023 mvetter@suse.com
- Update to version 0.8.6:
  * Increment version
  * cargo update: update dependencies
  * Add support for cargo-binstall to Cargo.toml
  * cargo update: update dependencies
  * Increment version
  * Fix: some panics are occuring when creating rayon
  * remove depth from config.toml and fix style issues
  * feat: default option for depth from config file
  * refactor: DisplayData
  * refactor: simplify filter.rs
  * Update README.md
* Mon Jan 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.8.4:
  * Increment version
  * fix: Stop progress indicator crashing into stderr
  * Feature: Add flag for screen readers
  * fix: Fix bug in progress bar
  * fix: only-dir flag conflicts with types
  * feature: --files-only -F
  * Update LICENSE
  * use create_dir_all instead of create_dir as that doesn't fail if the directory already exists, and make sure to propagate the error out
  * generate a man page as part of the build
  * clippy: Fix new clippy rules
  * upgrade dependencies
  * refactor: progress bar
  * refactor: progress bar
  * refactor: progress bar
  * Comment: Remove comment
  * Comment: update comment
  * Refactor: rename var
  * Refactor: PAtomicInfo class
  * Refactor: progress bar & file permissions
  * Refactor: progress bar: rename vars
  * Refactor: Progress bar: Remove atomic classes
  * Refactor: Progress bar: Remove PConfig
  * Refactor: progress bar: simplify
  * Refactor: progress bar: rm unused field
  * Refactor: Simplify progress indicator
  * refactor: update Progress bar: progress.rs
  * Refactor: Update main for progress bar
  * Refactor: Reduce complexity of progress bar code
  * Implemented a progress indicator (#275)
  * Fix: naming of parameter
  * [documentation] Note about running single-threaded
  * refactor dir_walker
  * feature: Support for dereference links -L follow
  * refactor create AggregateData for filter.rs
  * refactor filter.rs
  * refactor filter.rs
  * Fix: depth=0 bug for multiple arguments
  * fix: bug where hard links could be double counted
  * clippy: Fix new clippy
  * fix: update use of sysinfo.system
  * Update sysinfo version to 0.26.7
  * added deb-get as installation source
  * FEATURE: support only directories will be displayed. Flag -D
  * Read `inputs` from stdin when applicable
  * Add a direct dependency on the `atty` crate
* Fri Sep  2 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.8.3:
  * Fix: Only create large stack size if enough memory
  * Config file
  * New parameter: --min-size
  * New parameter: --skip-total
  * Does not include a space character as the first character in each line unless required
  * Fixes spurious permissions warning
  * Adds completion
* Thu Jul 14 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.8.1:
  * Allow -n to be used with -d
  * Tweak utils function
  * Fix archive/directory check in platform.rs
  * Improve help text
* Wed May 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version v0.8.0:
  * Increment version
  * Improve help text
* Sun Oct 31 2021 Enrico Belleri <idesmi@protonmail.com>
- initial package
